Class: Wreq::Jar
- Inherits:
-
Object
- Object
- Wreq::Jar
- Defined in:
- lib/wreq_ruby/cookie.rb
Instance Method Summary collapse
-
#inspect ⇒ String
Returns a short representation with the number of stored cookies.
Instance Method Details
#inspect ⇒ String
Returns a short representation with the number of stored cookies.
212 213 214 |
# File 'lib/wreq_ruby/cookie.rb', line 212 def inspect "#<Wreq::Jar [#{get_all.length} cookies]>" end |