Class: Wreq::Emulation
- Inherits:
-
Object
- Object
- Wreq::Emulation
- Defined in:
- lib/wreq_ruby/emulation.rb
Overview
Emulation option wrapper.
This class wraps device and OS emulation options and provides a unified interface for browser environment simulation. The actual implementation is provided by Rust for performance.
Class Method Summary collapse
Class Method Details
.new(device: nil, os: nil, skip_http2: false, skip_headers: false) ⇒ Object
199 200 |
# File 'lib/wreq_ruby/emulation.rb', line 199 def self.new(device: nil, os: nil, skip_http2: false, skip_headers: false) end |