Class: Wreq::Platform
- Inherits:
-
Object
- Object
- Wreq::Platform
- Defined in:
- lib/wreq_ruby/emulate.rb
Overview
Operating system platform enumeration backed by Rust.
Variants are exposed as constants under this class.
Each constant is an instance of Platform and can be passed to
Emulation.new via the platform: keyword.
Constant Summary collapse
- Windows =
nil- MacOS =
nil- Linux =
nil- Android =
nil- IOS =
nil
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
Value-based equality.
-
#eql?(other) ⇒ Boolean
Strict equality for Hash key and Set member semantics.
-
#hash ⇒ Integer
Hash value consistent with #eql? for use as Hash keys.
-
#to_s ⇒ String
Returns the platform name.
-
#to_sym ⇒ Symbol
Returns the platform as a lowercase symbol (e.g. :windows, :linux).
Instance Method Details
#==(other) ⇒ Boolean
Value-based equality.
237 238 |
# File 'lib/wreq_ruby/emulate.rb', line 237 def ==(other) end |
#eql?(other) ⇒ Boolean
Strict equality for Hash key and Set member semantics.
245 246 |
# File 'lib/wreq_ruby/emulate.rb', line 245 def eql?(other) end |
#hash ⇒ Integer
Hash value consistent with #eql? for use as Hash keys.
252 253 |
# File 'lib/wreq_ruby/emulate.rb', line 252 def hash end |
#to_s ⇒ String
Returns the platform name.
222 223 |
# File 'lib/wreq_ruby/emulate.rb', line 222 def to_s end |
#to_sym ⇒ Symbol
Returns the platform as a lowercase symbol (e.g. :windows, :linux).
229 230 |
# File 'lib/wreq_ruby/emulate.rb', line 229 def to_sym end |