Class: Wreq::Platform

Inherits:
Object
  • Object
show all
Defined in:
lib/wreq_ruby/emulate.rb

Overview

Operating system platform enumeration backed by Rust.

Variants are exposed as constants under this class. Each constant is an instance of Platform and can be passed to Emulation.new via the platform: keyword.

Examples:

Using a predefined platform

platform = Wreq::Platform::Windows
platform.class #=> Wreq::Platform

Applying a platform to emulation

emu = Wreq::Emulation.new(platform: Wreq::Platform::Windows)

Constant Summary collapse

Windows =
nil
MacOS =
nil
Linux =
nil
Android =
nil
IOS =
nil

Instance Method Summary collapse

Instance Method Details

#==(other) ⇒ Boolean

Value-based equality.

Parameters:

  • other (Object)

Returns:

  • (Boolean)


236
237
# File 'lib/wreq_ruby/emulate.rb', line 236

def ==(other)
end

#eql?(other) ⇒ Boolean

Strict equality for Hash key and Set member semantics.

Parameters:

  • other (Object)

Returns:

  • (Boolean)


244
245
# File 'lib/wreq_ruby/emulate.rb', line 244

def eql?(other)
end

#hashInteger

Hash value consistent with #eql? for use as Hash keys.

Returns:

  • (Integer)


251
252
# File 'lib/wreq_ruby/emulate.rb', line 251

def hash
end

#to_sString

Returns the platform name.

Returns:

  • (String)

    Platform name as a string



221
222
# File 'lib/wreq_ruby/emulate.rb', line 221

def to_s
end

#to_symSymbol

Returns the platform as a lowercase symbol (e.g. :windows, :linux).

Returns:

  • (Symbol)


228
229
# File 'lib/wreq_ruby/emulate.rb', line 228

def to_sym
end