Class: Wreq::Platform
- Inherits:
-
Object
- Object
- Wreq::Platform
- Defined in:
- lib/wreq_ruby/emulate.rb
Overview
Operating system platform enumeration backed by Rust.
Variants are exposed as constants under this class.
Each constant is an instance of Platform and can be passed to
Emulation.new via the platform: keyword.
Constant Summary collapse
- Windows =
nil- MacOS =
nil- Linux =
nil- Android =
nil- IOS =
nil
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
Value-based equality.
-
#eql?(other) ⇒ Boolean
Strict equality for Hash key and Set member semantics.
-
#hash ⇒ Integer
Hash value consistent with #eql? for use as Hash keys.
-
#to_s ⇒ String
Returns the platform name.
-
#to_sym ⇒ Symbol
Returns the platform as a lowercase symbol (e.g. :windows, :linux).
Instance Method Details
#==(other) ⇒ Boolean
Value-based equality.
236 237 |
# File 'lib/wreq_ruby/emulate.rb', line 236 def ==(other) end |
#eql?(other) ⇒ Boolean
Strict equality for Hash key and Set member semantics.
244 245 |
# File 'lib/wreq_ruby/emulate.rb', line 244 def eql?(other) end |
#hash ⇒ Integer
Hash value consistent with #eql? for use as Hash keys.
251 252 |
# File 'lib/wreq_ruby/emulate.rb', line 251 def hash end |
#to_s ⇒ String
Returns the platform name.
221 222 |
# File 'lib/wreq_ruby/emulate.rb', line 221 def to_s end |
#to_sym ⇒ Symbol
Returns the platform as a lowercase symbol (e.g. :windows, :linux).
228 229 |
# File 'lib/wreq_ruby/emulate.rb', line 228 def to_sym end |